==> mozile-0.7.0.zip: mozile/modules/CopyCutPaste/CopyCutPaste.js <==
// Copyright (C) 2005 The Mozile Team. See http://mozile.mozdev.org/ for details.

var f=new Array();f["File"]="CopyCutPaste/CopyCutPaste.js";f["Function"]="";Mozile.prototype.clipboard="";Mozile.prototype.doCopy=function(){var f=new Array();f["File"]="CopyCutPaste/CopyCutPaste.js";f["Function"]="Mozile.doCopy()";var copyStr=this.getSelection().toString();if(!mozile.extension&&(!this.moduleList["CopyCutPaste"]["requestPermissions"]||this.moduleList["CopyCutPaste"]["requestPermissions"]!="true")){this.clipboard=copyStr;}
else{try{netscape.security.PrivilegeManager.enablePrivilege("UniversalXPConnect UniversalBrowserWrite ");}
catch(e){return false;}
const gClipboardHelper=Components.classes["@mozilla.org/widget/clipboardhelper;1"].getService(Components.interfaces.nsIClipboardHelper);if(gClipboardHelper){gClipboardHelper.copyString(copyStr);}
else{this.clipboard=copyStr;}}
return copyStr;}
Mozile.prototype.doCut=function(){var f=new Array();f["File"]="CopyCutPaste/CopyCutPaste.js";f["Function"]="Mozile.doCut()";var copyStr=this.doCopy();if(copyStr){this.getSelection().deleteContents();return copyStr;}
else{return false;}}
Mozile.prototype.doPaste=function(){var f=new Array();f["File"]="CopyCutPaste/CopyCutPaste.js";f["Function"]="Mozile.doPaste()";if(!mozile.extension&&(!this.moduleList["CopyCutPaste"]["requestPermissions"]||this.moduleList["CopyCutPaste"]["requestPermissions"]!="true")){if(this.clipboard)this.insertString(this.clipboard);return this.clipboard;}
try{netscape.security.PrivilegeManager.enablePrivilege("UniversalXPConnect UniversalBrowserWrite ");}
catch(e){return false;}
var clip=Components.classes["@mozilla.org/widget/clipboard;1"].createInstance(Components.interfaces.nsIClipboard);if(!clip)return false;var trans=Components.classes["@mozilla.org/widget/transferable;1"].createInstance(Components.interfaces.nsITransferable);if(!trans)return false;trans.addDataFlavor("text/unicode");clip.getData(trans,clip.kGlobalClipboard);var str=new Object();var strLength=new Object();trans.getTransferData("text/unicode",str,strLength);if(str)
str=str.value.QueryInterface(Components.interfaces.nsISupportsString);else{return false;}
if(str)
pasteText=str.data.substring(0,strLength.value/2);else{return false;}
this.insertString(pasteText)
return pasteText;}
var mozileCopy=mozile.rootCommandList.createCommand("MozileCommand: id=Mozile-Copy, label=Copy, tooltip='Copy selection', accelerator='Command-C', image='"+mozile.root+"images/copy.png'");mozileCopy.command=function(){var f=new Array();f["File"]="CopyCutPaste/CopyCutPaste.js";f["Function"]="mozileCopy.command";mozile.doCopy();}
var mozileCut=mozile.rootCommandList.createCommand("MozileCommand: id=Mozile-Cut, label=Cut, tooltip='Cut selection', accelerator='Command-X', image='"+mozile.root+"images/cut.png'");mozileCut.command=function(){var f=new Array();f["File"]="CopyCutPaste/CopyCutPaste.js";f["Function"]="mozileCut.command";mozile.doCut();}
var mozilePaste=mozile.rootCommandList.createCommand("MozileCommand: id=Mozile-Paste, label=Paste, tooltip='Paste selection', accelerator='Command-V', image='"+mozile.root+"images/paste.png'");mozilePaste.command=function(){var f=new Array();f["File"]="CopyCutPaste/CopyCutPaste.js";f["Function"]="mozilePaste.command";mozile.doPaste();}
mozile.registerModule("CopyCutPaste","0.0.1");

==> mozile-0.7.1.zip: mozile/modules/CopyCutPaste/CopyCutPaste.js <==
// Copyright (C) 2006 The Mozile Team. See http://mozile.mozdev.org/ for details.

var f=new Array();f["File"]="CopyCutPaste/CopyCutPaste.js";f["Function"]="";Mozile.prototype.clipboard="";Mozile.prototype.doCopy=function(){var f=new Array();f["File"]="CopyCutPaste/CopyCutPaste.js";f["Function"]="Mozile.doCopy()";var copyStr=this.getSelection().toString();if(!mozile.extension&&(!this.moduleList["CopyCutPaste"]["requestPermissions"]||this.moduleList["CopyCutPaste"]["requestPermissions"]!="true")){this.clipboard=copyStr;}
else{try{netscape.security.PrivilegeManager.enablePrivilege("UniversalXPConnect UniversalBrowserWrite ");}
catch(e){return false;}
const gClipboardHelper=Components.classes["@mozilla.org/widget/clipboardhelper;1"].getService(Components.interfaces.nsIClipboardHelper);if(gClipboardHelper){gClipboardHelper.copyString(copyStr);}
else{this.clipboard=copyStr;}}
return copyStr;}
Mozile.prototype.doCut=function(){var f=new Array();f["File"]="CopyCutPaste/CopyCutPaste.js";f["Function"]="Mozile.doCut()";var copyStr=this.doCopy();if(copyStr){this.getSelection().deleteContents();return copyStr;}
else{return false;}}
Mozile.prototype.doPaste=function(){var f=new Array();f["File"]="CopyCutPaste/CopyCutPaste.js";f["Function"]="Mozile.doPaste()";if(!mozile.extension&&(!this.moduleList["CopyCutPaste"]["requestPermissions"]||this.moduleList["CopyCutPaste"]["requestPermissions"]!="true")){if(this.clipboard)this.insertString(this.clipboard);return this.clipboard;}
try{netscape.security.PrivilegeManager.enablePrivilege("UniversalXPConnect UniversalBrowserWrite ");}
catch(e){return false;}
var clip=Components.classes["@mozilla.org/widget/clipboard;1"].createInstance(Components.interfaces.nsIClipboard);if(!clip)return false;var trans=Components.classes["@mozilla.org/widget/transferable;1"].createInstance(Components.interfaces.nsITransferable);if(!trans)return false;trans.addDataFlavor("text/unicode");clip.getData(trans,clip.kGlobalClipboard);var str=new Object();var strLength=new Object();trans.getTransferData("text/unicode",str,strLength);if(str)
str=str.value.QueryInterface(Components.interfaces.nsISupportsString);else{return false;}
if(str)
pasteText=str.data.substring(0,strLength.value/2);else{return false;}
this.insertString(pasteText)
return pasteText;}
if(mozile.rootCommandList){var mozileCopy=mozile.rootCommandList.createCommand("MozileCommand: id=Mozile-Copy, label=Copy, tooltip='Copy selection', accelerator='Command-C', image='"+mozile.root+"images/copy.png'");mozileCopy.command=function(){var f=new Array();f["File"]="CopyCutPaste/CopyCutPaste.js";f["Function"]="mozileCopy.command";mozile.doCopy();return true;}
var mozileCut=mozile.rootCommandList.createCommand("MozileCommand: id=Mozile-Cut, label=Cut, tooltip='Cut selection', accelerator='Command-X', image='"+mozile.root+"images/cut.png'");mozileCut.command=function(){var f=new Array();f["File"]="CopyCutPaste/CopyCutPaste.js";f["Function"]="mozileCut.command";mozile.doCut();return true;}
var mozilePaste=mozile.rootCommandList.createCommand("MozileCommand: id=Mozile-Paste, label=Paste, tooltip='Paste selection', accelerator='Command-V', image='"+mozile.root+"images/paste.png'");mozilePaste.command=function(){var f=new Array();f["File"]="CopyCutPaste/CopyCutPaste.js";f["Function"]="mozilePaste.command";mozile.doPaste();return true;}}
mozile.registerModule("CopyCutPaste","0.0.1");
